<?php
/**
* @package phpBB Extension - Birthdays
* @copyright (c) 2023 Sniper_E - https://www.sniper-e.net
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*/

namespace sniper\birthdays\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{
	/** @var \phpbb\template\template */
	protected $template;

	/** @var \phpbb\extension\manager */
	protected $extension_manager;
	
	/**
	* Constructor
	*
	* @param \phpbb\template\template	$template
	* @param \phpbb\extension\manager 	$extension_manager
	*
	*/
	public function __construct(
		\phpbb\template\template $template,
		\phpbb\extension\manager $extension_manager
	)
	{
		$this->template           = $template;
		$this->extension_manager  = $extension_manager;
	}

	static public function getSubscribedEvents()
	{
		return array(
			'core.page_header' => 'page_header',
		);
	}

	public function page_header($event)
	{
		$this->assign_authors();
	}

	protected function assign_authors()
	{
		$md_manager = $this->extension_manager->create_extension_metadata_manager('sniper/birthdays', $this->template);
		$meta = $md_manager->get_metadata();
		$author_homepages = array();

		foreach (array_slice($meta['authors'], 0, 1) as $author)
		{
			$author_homepages[] = sprintf('<a href="%1$s">%2$s</a>', $author['homepage'], $author['name']);
		}

		$this->template->assign_vars(array(
			'BIRTHDAYS_DISPLAY_NAME'      => $meta['extra']['display-name'],
			'BIRTHDAYS_DISCRIPTION'       => $meta['description'],
			'BIRTHDAYS_VERSION'           => $meta['version'],
			'BIRTHDAYS_TOPIC'             => $meta['extra']['topicpage'],
			'BIRTHDAYS_AUTHOR_HOMEPAGES'  => implode(' &amp; ', $author_homepages),
		));
	}
}
